.. _fanc-compatibility:

===========================
FAN-C compatibility modules
===========================

.. toctree::
   :maxdepth: 1

   Juicer <compatibility/juicer>
   Cooler <compatibility/cooler>
